==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
export let WebInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebInputDescriptionMetadata extends Base {
        static b(a) {
            if (WebInputDescriptionMetadata.a == null) {
                WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
            }
            if (a.k(WebInputDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebInputDescriptionMetadata.a);
            WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Input");
            a.item("__tagNameWC", "String:igc-input");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
            a.item("DisplayType@stringUnion", "WebComponents;React");
            a.item("DisplayType@names", "Number;Email;Password;Search;Tel;Text;Url");
            a.item("Inputmode", "ExportedType:string:InputInputmode");
            a.item("Inputmode@stringUnion", "WebComponents;React");
            a.item("Inputmode@names", "None;Email;Search;Tel;Url;Txt;Decimal;Numeric");
            a.item("Pattern", "String");
            a.item("MinLength", "Number:double");
            a.item("Minlength", "Number:double");
            a.item("MaxLength", "Number:double");
            a.item("Maxlength", "Number:double");
            a.item("Min", "String");
            a.item("Max", "String");
            a.item("Step", "Number:double");
            a.item("Autofocus", "Boolean");
            a.item("Autocomplete", "String");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebInputDescriptionMetadata.b(a);
            a.ad("WebInput", () => new WebInputDescription());
            a.ac("WebInput", WebInputDescriptionMetadata.a);
        }
    }
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
})();

==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
import { WebInputDescription } from "./WebInputDescription";
/**
 * @hidden
 */
export let WebInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebInputDescriptionMetadata extends Base {
        static b(a) {
            if (WebInputDescriptionMetadata.a == null) {
                WebInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebInputDescriptionMetadata.c(WebInputDescriptionMetadata.a);
            }
            if (a.k(WebInputDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebInputDescriptionMetadata.a);
            WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Input");
            a.item("__tagNameWC", "String:igc-input");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "String");
            a.item("DisplayType", "(wc:Type)ExportedType:string:InputType");
            a.item("DisplayType@stringUnion", "WebComponents;React");
            a.item("DisplayType@names", "Text;Email;Number;Password;Search;Tel;Url");
            a.item("InputMode", "String");
            a.item("Pattern", "String");
            a.item("MinLength", "Number:double");
            a.item("MaxLength", "Number:double");
            a.item("Min", "String");
            a.item("Max", "String");
            a.item("Step", "Number:double");
            a.item("Autofocus", "Boolean");
            a.item("Autocomplete", "String");
            a.item("ValidateOnly", "Boolean");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebInputDescriptionMetadata.b(a);
            a.ae("WebInput", () => new WebInputDescription());
            a.ad("WebInput", WebInputDescriptionMetadata.a);
        }
    }
    WebInputDescriptionMetadata.$t = markType(WebInputDescriptionMetadata, 'WebInputDescriptionMetadata');
    WebInputDescriptionMetadata.a = null;
    return WebInputDescriptionMetadata;
})();
